nxp-pac

Crates

git

Versions

lpc55s16

Flavors

Cccr

Struct Cccr 

#[repr(transparent)]
pub struct Cccr(pub u32);
CC Control Register

Tuple Fields

0: u32

Implementations

Source

impl Cccr

pub const fn init(&self) -> bool

Initialization.

pub const fn set_init(&mut self, val: bool)

Initialization.

pub const fn cce(&self) -> bool

Configuration change enable.

pub const fn set_cce(&mut self, val: bool)

Configuration change enable.

pub const fn asm(&self) -> bool

Restricted operational mode.

pub const fn set_asm(&mut self, val: bool)

Restricted operational mode.

pub const fn csa(&self) -> bool

Clock Stop Acknowledge.

pub const fn set_csa(&mut self, val: bool)

Clock Stop Acknowledge.

pub const fn csr(&self) -> bool

Clock Stop Request.

pub const fn set_csr(&mut self, val: bool)

Clock Stop Request.

pub const fn mon(&self) -> bool

Bus monitoring mode.

pub const fn set_mon(&mut self, val: bool)

Bus monitoring mode.

pub const fn dar(&self) -> bool

Disable automatic retransmission.

pub const fn set_dar(&mut self, val: bool)

Disable automatic retransmission.

pub const fn test(&self) -> bool

Test mode enable.

pub const fn set_test(&mut self, val: bool)

Test mode enable.

pub const fn fdoe(&self) -> bool

CAN FD operation enable.

pub const fn set_fdoe(&mut self, val: bool)

CAN FD operation enable.

pub const fn brse(&self) -> bool

When CAN FD operation is disabled, this bit is not evaluated.

pub const fn set_brse(&mut self, val: bool)

When CAN FD operation is disabled, this bit is not evaluated.

pub const fn pxhd(&self) -> bool

Protocol exception handling disable.

pub const fn set_pxhd(&mut self, val: bool)

Protocol exception handling disable.

pub const fn efbi(&self) -> bool

Edge filtering during bus integration.

pub const fn set_efbi(&mut self, val: bool)

Edge filtering during bus integration.

pub const fn txp(&self) -> bool

Transmit pause.

pub const fn set_txp(&mut self, val: bool)

Transmit pause.

pub const fn niso(&self) -> bool

Non ISO operation.

pub const fn set_niso(&mut self, val: bool)

Non ISO operation.