Struct Ils
Source #[repr(transparent)]
pub struct Ils(pub u32);
Rx FIFO 0 new message interrupt line.
Rx FIFO 0 new message interrupt line.
Rx FIFO 0 watermark reached interrupt line.
Rx FIFO 0 watermark reached interrupt line.
Rx FIFO 0 full interrupt line.
Rx FIFO 0 full interrupt line.
Rx FIFO 0 message lost interrupt line.
Rx FIFO 0 message lost interrupt line.
Rx FIFO 1 new message interrupt line.
Rx FIFO 1 new message interrupt line.
Rx FIFO 1 watermark reached interrupt line.
Rx FIFO 1 watermark reached interrupt line.
Rx FIFO 1 full interrupt line.
Rx FIFO 1 full interrupt line.
Rx FIFO 1 message lost interrupt line.
Rx FIFO 1 message lost interrupt line.
High priority message interrupt line.
High priority message interrupt line.
Transmission completed interrupt line.
Transmission completed interrupt line.
Transmission cancellation finished interrupt line.
Transmission cancellation finished interrupt line.
Tx FIFO empty interrupt line.
Tx FIFO empty interrupt line.
Tx event FIFO new entry interrupt line.
Tx event FIFO new entry interrupt line.
Tx event FIFO watermark reached interrupt line.
Tx event FIFO watermark reached interrupt line.
Tx event FIFO full interrupt line.
Tx event FIFO full interrupt line.
Tx event FIFO element lost interrupt line.
Tx event FIFO element lost interrupt line.
Timestamp wraparound interrupt line.
Timestamp wraparound interrupt line.
Message RAM access failure interrupt line.
Message RAM access failure interrupt line.
Timeout occurred interrupt line.
Timeout occurred interrupt line.
Message stored in dedicated Rx buffer interrupt line.
Message stored in dedicated Rx buffer interrupt line.
Bit error corrected interrupt line.
Bit error corrected interrupt line.
Bit error uncorrected interrupt line.
Bit error uncorrected interrupt line.
Error logging overflow interrupt line.
Error logging overflow interrupt line.
Error passive interrupt line.
Error passive interrupt line.
Warning status interrupt line.
Warning status interrupt line.
Bus_Off Status interrupt line.
Bus_Off Status interrupt line.
Protocol error in arbitration phase interrupt line.
Protocol error in arbitration phase interrupt line.
Protocol error in data phase interrupt line.
Protocol error in data phase interrupt line.
Access to reserved address interrupt line.
Access to reserved address interrupt line.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.