Struct Ir
Source #[repr(transparent)]
pub struct Ir(pub u32);
Rx FIFO 0 watermark reached.
Rx FIFO 0 watermark reached.
Rx FIFO 1 watermark reached.
Rx FIFO 1 watermark reached.
Transmission cancellation finished.
Transmission cancellation finished.
Tx event FIFO watermark reached.
Tx event FIFO watermark reached.
Tx event FIFO element lost.
Tx event FIFO element lost.
Message RAM access failure.
Message RAM access failure.
Message stored in dedicated Rx buffer.
Message stored in dedicated Rx buffer.
Protocol error in arbitration phase.
Protocol error in arbitration phase.
Protocol error in data phase.
Protocol error in data phase.
Access to reserved address.
Access to reserved address.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.