nxp-pac

Crates

git

Versions

lpc55s16

Flavors

Tscc

Struct Tscc 

#[repr(transparent)]
pub struct Tscc(pub u32);
Timestamp Counter Configuration

Tuple Fields

0: u32

Implementations

Source

impl Tscc

pub const fn tss(&self) -> u8

Timestamp select.

pub const fn set_tss(&mut self, val: u8)

Timestamp select.

pub const fn tcp(&self) -> u8

Timestamp counter prescaler Configures the timestamp and timeout counters time unit in multiple of CAN bit times.

pub const fn set_tcp(&mut self, val: u8)

Timestamp counter prescaler Configures the timestamp and timeout counters time unit in multiple of CAN bit times.