Struct Cccr
Source #[repr(transparent)]
pub struct Cccr(pub u32);
Configuration change enable.
Configuration change enable.
Restricted operational mode.
Restricted operational mode.
Disable automatic retransmission.
Disable automatic retransmission.
When CAN FD operation is disabled, this bit is not evaluated.
When CAN FD operation is disabled, this bit is not evaluated.
Protocol exception handling disable.
Protocol exception handling disable.
Edge filtering during bus integration.
Edge filtering during bus integration.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.